@@ -101,13 +101,15 @@ sync
 # Seriously damage cache metadata
 aux error_dev "$dev1" 2054:2
 
-# Here we usually for the 1st. notice needs_check
-check lv_attr_bit state $vg/$lv1 "c"
-
-sleep .1
-
-# And now cache is finaly Failed
-check lv_attr_bit health $vg/$lv1 "F"
+# On fixed kernel we get instant Fail here
+get lv_field  $vg/$lv1 lv_attr | tee out
+grep "Cwi-a-C-F-" out || {
+	# while on older unfixed we just notice needs_check
+	grep "Cwi-c-C---" out
+	sleep .1
+	# And now cache is finaly Failed
+	check lv_attr_bit health $vg/$lv1 "F"
+}
 check lv_field $vg/$lv1 lv_health_status "failed"
 
 aux disable_dev "$dev1"
